==> eam-wshub-proxyclient-11.4-12-sources.jar: net/datastream/schemas/mp_fields/INSPECTIONPOINTROUTEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour INSPECTIONPOINTROUTEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="INSPECTIONPOINTROUTEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ROUTEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SEQUENCENUMBER"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "INSPECTIONPOINTROUTEID_Type", propOrder = {
    "routeid",
    "sequencenumber"
})
public class INSPECTIONPOINTROUTEID_Type {

    @XmlElement(name = "ROUTEID", required = true)
    protected ROUTE_Type routeid;
    @XmlElement(name = "SEQUENCENUMBER")
    protected long sequencenumber;

    /**
     * Obtient la valeur de la propriété routeid.
     * 
     * @return
     *     possible object is
     *     {@link ROUTE_Type }
     *     
     */
    public ROUTE_Type getROUTEID() {
        return routeid;
    }

    /**
     * Définit la valeur de la propriété routeid.
     * 
     * @param value
     *     allowed object is
     *     {@link ROUTE_Type }
     *     
     */
    public void setROUTEID(ROUTE_Type value) {
        this.routeid = value;
    }

    /**
     * Obtient la valeur de la propriété sequencenumber.
     * 
     */
    public long getSEQUENCENUMBER() {
        return sequencenumber;
    }

    /**
     * Définit la valeur de la propriété sequencenumber.
     * 
     */
    public void setSEQUENCENUMBER(long value) {
        this.sequencenumber = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/INSPECTIONPOINTROUTEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for INSPECTIONPOINTROUTEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="INSPECTIONPOINTROUTEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ROUTEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SEQUENCENUMBER"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "INSPECTIONPOINTROUTEID_Type", propOrder = {
    "routeid",
    "sequencenumber"
})
public class INSPECTIONPOINTROUTEID_Type {

    @XmlElement(name = "ROUTEID", required = true)
    protected ROUTE_Type routeid;
    @XmlElement(name = "SEQUENCENUMBER")
    protected long sequencenumber;

    /**
     * Gets the value of the routeid property.
     * 
     * @return
     *     possible object is
     *     {@link ROUTE_Type }
     *     
     */
    public ROUTE_Type getROUTEID() {
        return routeid;
    }

    /**
     * Sets the value of the routeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ROUTE_Type }
     *     
     */
    public void setROUTEID(ROUTE_Type value) {
        this.routeid = value;
    }

    /**
     * Gets the value of the sequencenumber property.
     * 
     */
    public long getSEQUENCENUMBER() {
        return sequencenumber;
    }

    /**
     * Sets the value of the sequencenumber property.
     * 
     */
    public void setSEQUENCENUMBER(long value) {
        this.sequencenumber = value;
    }

}
